==> haskell-pretty-show-1.7-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pretty-show
version: 1.7
id: pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
key: pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
license: MIT
maintainer: iavor.diatchki@gmail.com
author: Iavor S. Diatchki
homepage: http://wiki.github.com/yav/pretty-show
synopsis: Tools for working with derived `Show` instances and generic
          inspection of values.
description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.
category: Text
abi: 7f72f065bf630927a07ec77462e0c52e
exposed: True
exposed-modules:
    Text.Show.Pretty
hidden-modules: Text.Show.Html Text.Show.Parser Text.Show.Value
                Text.Show.PrettyVal Paths_pretty_show
import-dirs: /usr/lib/ghc-8.4.3/site-local/pretty-show-1.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/pretty-show-1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pretty-show
hs-libraries: HSpretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
depends:
    array-0.5.2.0 base-4.11.1.0
    haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3 pretty-1.1.3.6
    text-1.2.3.0 filepath-1.4.2 ghc-prim-0.5.2.0
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3=031c68d5bbb9ae48cb447f84f1dce56a
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html: /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-show-1.8.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pretty-show
version: 1.8.1
id: pretty-show-1.8.1-7H0L2aT0WSVIsk7RM7bmlH
key: pretty-show-1.8.1-7H0L2aT0WSVIsk7RM7bmlH
license: MIT
maintainer: iavor.diatchki@gmail.com
author: Iavor S. Diatchki
homepage: http://wiki.github.com/yav/pretty-show
synopsis: Tools for working with derived `Show` instances and generic
          inspection of values.
description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.
category: Text
abi: 8a070f0bc695078286ea307e4ff7a440
exposed: True
exposed-modules:
    Text.Show.Pretty
hidden-modules: Text.Show.Html Text.Show.Parser Text.Show.Value
                Text.Show.PrettyVal Paths_pretty_show
import-dirs: /usr/lib/ghc-8.4.3/site-local/pretty-show-1.8.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/pretty-show-1.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-pretty-show
hs-libraries: HSpretty-show-1.8.1-7H0L2aT0WSVIsk7RM7bmlH
depends:
    array-0.5.2.0 base-4.11.1.0
    haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3 pretty-1.1.3.6
    text-1.2.3.0 filepath-1.4.2 ghc-prim-0.5.2.0
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-lexer-1.0.1-HlkkvdCF1kAJ83VbVeDzK3=031c68d5bbb9ae48cb447f84f1dce56a
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html: /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
